@@ -75,13 +75,17 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
                     noAccountFoundDialog = cutetubedialogs.NoAccountFoundDialog(self)
             else:
                 username = YouTubeAPISettings.defaultUser
-                YouTubeDataService.youtubeLogin(username)
-                QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
+                if YouTubeDataService.youtubeLogin(username) == True:
+                    QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
+                else:
+                    QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account")
         except:
             try:
                 username = YouTubeAPISettings.userDict.keys()[0]
-                YouTubeDataService.youtubeLogin(username)
-                QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
+                if YouTubeDataService.youtubeLogin(username) == True:
+                    QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
+                else:
+                    QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account")
             except:
                 QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account")
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
